=== modified file 'annotate/config.py'
--- annotate/config.py	2012-02-09 02:55:06 +0000
+++ annotate/config.py	2011-09-05 03:44:26 +0000
@@ -62,8 +62,7 @@
         self.pane.set_position(self['window'].as_int('pane_position'))
         self.window.set_default_size(self['window'].as_int('width'),
                                      self['window'].as_int('height'))
-        self.window.move(
-            self['window'].as_int('x'), self['window'].as_int('y'))
+        self.window.move(self['window'].as_int('x'), self['window'].as_int('y'))
 
         if self['window'].as_bool('maximized'):
             self.window.maximize()
@@ -72,6 +71,7 @@
         self.window.connect("destroy", self._write)
         self.window.connect("configure-event", self._save_window_props)
         self.window.connect("window-state-event", self._save_window_props)
+        self.pane.connect("notify", self._save_pane_props)
 
     def _save_window_props(self, w, e, *args):
         if e.window.get_state() & Gdk.WindowState.MAXIMIZED:
@@ -83,11 +83,14 @@
         self["window"]["maximized"] = maximized
         return False
 
-    def _save_pane_props(self):
-        self["window"]["pane_position"] = self.pane.get_position()
+    def _save_pane_props(self, w, gparam):
+        if gparam and gparam.name == "position":
+            self["window"]["pane_position"] = w.get_position()
+
+        return False
 
     def _write(self, *args):
-        self._save_pane_props()
         config.ensure_config_dir_exists()
         self.write()
         return False
+

=== modified file 'annotate/gannotate.py'
--- annotate/gannotate.py	2012-02-09 01:56:37 +0000
+++ annotate/gannotate.py	2011-11-17 21:27:30 +0000
@@ -220,7 +220,7 @@
         hbox.show()
         vbox.pack_start(hbox, False, True, 0)
 
-        self.pane = pane = Gtk.Paned.new(Gtk.Orientation.VERTICAL)
+        self.pane = pane = Gtk.VPaned()
         pane.add1(swbox)
         pane.add2(self.revisionview)
         pane.show()

=== modified file 'bzr-handle-patch'
--- bzr-handle-patch	2012-02-03 22:55:40 +0000
+++ bzr-handle-patch	2011-07-31 16:50:29 +0000
@@ -2,8 +2,9 @@
 
 from bzrlib import errors, merge_directive
 from bzrlib.plugin import load_plugins
+from bzrlib.plugins.gtk.commands import open_display
+
 load_plugins()
-from bzrlib.plugins.gtk.commands import open_display
 
 import sys
 
@@ -31,13 +32,9 @@
 	window = controller.window
 	window.show()
 	Gtk = open_display()
-	window.connect("destroy", Gtk.main_quit)
+	window.connect("destroy", gtk.main_quit)
 except Exception, e:
 	from bzrlib.plugins.gtk.dialog import error_dialog
 	error_dialog('Error', str(e))
 	raise
-
-if len(sys.argv) == 3 and sys.argv[2] == 'test':
-    sys.exit(0)
-
-Gtk.main()
+gtk.main()

=== modified file 'diff.py'
--- diff.py	2012-02-05 05:14:11 +0000
+++ diff.py	2012-01-23 21:47:33 +0000
@@ -10,8 +10,23 @@
 
 from cStringIO import StringIO
 
+import os
+import re
 import sys
 import inspect
+try:
+    from xml.etree.ElementTree import (
+        Element,
+        SubElement,
+        tostring,
+        )
+    Element, SubElement, tostring  # Hush PEP8 redefinition.
+except ImportError:
+    from elementtree.ElementTree import (
+        Element,
+        SubElement,
+        tostring,
+        )
 
 from gi.repository import Gtk
 from gi.repository import Pango
@@ -20,6 +35,11 @@
     have_gtksourceview = True
 except ImportError:
     have_gtksourceview = False
+try:
+    from gi.repository import GConf
+    have_gconf = True
+except ImportError:
+    have_gconf = False
 
 from bzrlib import (
     errors,
@@ -30,6 +50,7 @@
     )
 from bzrlib.diff import show_diff_trees
 from bzrlib.patches import parse_patches
+from bzrlib.trace import warning
 from bzrlib.plugins.gtk.dialog import (
     error_dialog,
     info_dialog,
@@ -55,8 +76,6 @@
 class DiffFileView(Gtk.ScrolledWindow):
     """Window for displaying diffs from a diff file"""
 
-    SHOW_WIDGETS = True
-
     def __init__(self):
         super(DiffFileView, self).__init__()
         self.construct()
@@ -70,18 +89,136 @@
             self.buffer = GtkSource.Buffer()
             lang_manager = GtkSource.LanguageManager.get_default()
             language = lang_manager.guess_language(None, "text/x-patch")
+            if have_gconf:
+                self.apply_gedit_colors(self.buffer)
+            self.apply_colordiff_colors(self.buffer)
             self.buffer.set_language(language)
             self.buffer.set_highlight_syntax(True)
+
             self.sourceview = GtkSource.View(buffer=self.buffer)
         else:
             self.buffer = Gtk.TextBuffer()
             self.sourceview = Gtk.TextView(self.buffer)
 
         self.sourceview.set_editable(False)
-        self.sourceview.override_font(Pango.FontDescription("Monospace"))
+        self.sourceview.modify_font(Pango.FontDescription("Monospace"))
         self.add(self.sourceview)
-        if self.SHOW_WIDGETS:
-            self.sourceview.show()
+        self.sourceview.show()
+
+    @staticmethod
+    def apply_gedit_colors(buf):
+        """Set style to that specified in gedit configuration.
+
+        This method needs the gconf module.
+
+        :param buf: a GtkSource.Buffer object.
+        """
+        GEDIT_SCHEME_PATH = '/apps/gedit-2/preferences/editor/colors/scheme'
+        GEDIT_USER_STYLES_PATH = os.path.expanduser('~/.gnome2/gedit/styles')
+
+        client = GConf.Client.get_default()
+        style_scheme_name = client.get_string(GEDIT_SCHEME_PATH)
+        if style_scheme_name is not None:
+            style_scheme_mgr = GtkSource.StyleSchemeManager()
+            style_scheme_mgr.append_search_path(GEDIT_USER_STYLES_PATH)
+
+            style_scheme = style_scheme_mgr.get_scheme(style_scheme_name)
+
+            if style_scheme is not None:
+                buf.set_style_scheme(style_scheme)
+
+    @classmethod
+    def apply_colordiff_colors(klass, buf):
+        """Set style colors for lang using the colordiff configuration file.
+
+        Both ~/.colordiffrc and ~/.colordiffrc.bzr-gtk are read.
+
+        :param buf: a "Diff" GtkSource.Buffer object.
+        """
+        scheme_manager = GtkSource.StyleSchemeManager()
+        style_scheme = scheme_manager.get_scheme('colordiff')
+
+        # if style scheme not found, we'll generate it from colordiffrc
+        # TODO: reload if colordiffrc has changed.
+        if style_scheme is None:
+            colors = {}
+
+            for f in ('~/.colordiffrc', '~/.colordiffrc.bzr-gtk'):
+                f = os.path.expanduser(f)
+                if os.path.exists(f):
+                    try:
+                        f = file(f)
+                    except IOError, e:
+                        warning('could not open file %s: %s' % (f, str(e)))
+                    else:
+                        colors.update(klass.parse_colordiffrc(f))
+                        f.close()
+
+            if not colors:
+                # ~/.colordiffrc does not exist
+                return
+
+            mapping = {
+                # map GtkSourceView2 scheme styles to colordiff names
+                # since GSV is richer, accept new names for extra bits,
+                # defaulting to old names if they're not present
+                'diff:added-line': ['newtext'],
+                'diff:removed-line': ['oldtext'],
+                'diff:location': ['location', 'diffstuff'],
+                'diff:file': ['file', 'diffstuff'],
+                'diff:special-case': ['specialcase', 'diffstuff'],
+            }
+
+            converted_colors = {}
+            for name, values in mapping.items():
+                color = None
+                for value in values:
+                    color = colors.get(value, None)
+                    if color is not None:
+                        break
+                if color is None:
+                    continue
+                converted_colors[name] = color
+
+            # some xml magic to produce needed style scheme description
+            e_style_scheme = Element('style-scheme')
+            e_style_scheme.set('id', 'colordiff')
+            e_style_scheme.set('_name', 'ColorDiff')
+            e_style_scheme.set('version', '1.0')
+            for name, color in converted_colors.items():
+                style = SubElement(e_style_scheme, 'style')
+                style.set('name', name)
+                style.set('foreground', '#%s' % color)
+
+            scheme_xml = tostring(e_style_scheme, 'UTF-8')
+            if not os.path.exists(os.path.expanduser(
+                '~/.local/share/gtksourceview-2.0/styles')):
+                os.makedirs(os.path.expanduser(
+                    '~/.local/share/gtksourceview-2.0/styles'))
+            file(os.path.expanduser(
+                '~/.local/share/gtksourceview-2.0/styles/colordiff.xml'),
+                'w').write(scheme_xml)
+
+            scheme_manager.force_rescan()
+            style_scheme = scheme_manager.get_scheme('colordiff')
+
+        buf.set_style_scheme(style_scheme)
+
+    @staticmethod
+    def parse_colordiffrc(fileobj):
+        """Parse fileobj as a colordiff configuration file.
+
+        :return: A dict with the key -> value pairs.
+        """
+        colors = {}
+        for line in fileobj:
+            if re.match(r'^\s*#', line):
+                continue
+            if '=' not in line:
+                continue
+            key, val = line.split('=', 1)
+            colors[key.strip()] = val.strip()
+        return colors
 
     def set_trees(self, rev_tree, parent_tree):
         self.rev_tree = rev_tree
@@ -298,12 +435,10 @@
     differences between two revisions on a branch.
     """
 
-    SHOW_WIDGETS = True
-
     def __init__(self, parent=None, operations=None):
         super(DiffWindow, self).__init__(parent=parent)
         self.set_border_width(0)
-        self.set_title("bzr diff")
+        self.set_title("bzrk diff")
 
         # Use two thirds of the screen by default
         screen = self.get_screen()
@@ -317,12 +452,10 @@
         """Construct the window contents."""
         self.vbox = Gtk.VBox()
         self.add(self.vbox)
-        if self.SHOW_WIDGETS:
-            self.vbox.show()
+        self.vbox.show()
         self.diff = DiffWidget()
         self.vbox.pack_end(self.diff, True, True, 0)
-        if self.SHOW_WIDGETS:
-            self.diff.show_all()
+        self.diff.show_all()
         # Build after DiffWidget to connect signals
         menubar = self._get_menu_bar()
         self.vbox.pack_start(menubar, False, False, 0)
@@ -338,11 +471,13 @@
         mb_view_wrapsource = Gtk.CheckMenuItem.new_with_mnemonic(
             _i18n("Wrap _Long Lines"))
         mb_view_wrapsource.connect('activate', self.diff._on_wraplines_toggled)
+        mb_view_wrapsource.show()
         mb_view_menu.append(mb_view_wrapsource)
+        mb_view.show()
         mb_view.set_submenu(mb_view_menu)
+        mb_view.show()
         menubar.append(mb_view)
-        if self.SHOW_WIDGETS:
-            menubar.show_all()
+        menubar.show()
         return menubar
 
     def _get_button_bar(self, operations):
@@ -356,13 +491,11 @@
         hbox.set_layout(Gtk.ButtonBoxStyle.START)
         for title, method in operations:
             merge_button = Gtk.Button(title)
-            if self.SHOW_WIDGETS:
-                merge_button.show()
+            merge_button.show()
             merge_button.set_relief(Gtk.ReliefStyle.NONE)
             merge_button.connect("clicked", method)
-            hbox.pack_start(merge_button, False, True, 0)
-        if self.SHOW_WIDGETS:
-            hbox.show()
+            hbox.pack_start(merge_button, expand=False, fill=True)
+        hbox.show()
         return hbox
 
     def _get_merge_target(self):

=== modified file 'missing.py'
--- missing.py	2012-02-09 03:43:01 +0000
+++ missing.py	2011-08-13 03:06:56 +0000
@@ -47,7 +47,7 @@
 
     def _create(self):
         self.set_default_size(600, 600)
-        paned = Gtk.Paned.new(Gtk.Orientation.VERTICAL)
+        paned = Gtk.VPaned()
 
         frame = Gtk.Frame(label="You have the following extra revisions:")
 

=== modified file 'preferences/plugins.py'
--- preferences/plugins.py	2012-02-09 03:43:01 +0000
+++ preferences/plugins.py	2012-02-03 18:08:07 +0000
@@ -17,11 +17,10 @@
 from gi.repository import Gtk
 
 
-class PluginsPage(Gtk.Paned):
+class PluginsPage(Gtk.VPaned):
 
     def __init__(self):
         super(PluginsPage, self).__init__()
-        self.set_orientation(Gtk.Orientation.VERTICAL)
         self.set_border_width(12)
         self.set_position(216)
 

=== modified file 'tags.py'
--- tags.py	2012-02-09 03:43:01 +0000
+++ tags.py	2011-09-05 03:44:26 +0000
@@ -15,6 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+from gi.repository import GObject
 from gi.repository import Gtk
 
 from bzrlib.plugins.gtk.dialog import error_dialog
@@ -46,7 +47,7 @@
         self._vbox_buttons = Gtk.VBox()
         self._vbox_buttons_top = Gtk.VBox()
         self._vbox_buttons_bottom = Gtk.VBox()
-        self._vpaned = Gtk.Paned.new(Gtk.Orientation.VERTICAL)
+        self._vpaned = Gtk.VPaned()
 
         # Set callbacks
         self._button_add.connect('clicked', self._on_add_clicked)
@@ -197,8 +198,6 @@
         # Refresh RevisionView only if there are tags available
         if not self._no_tags:
             (path, col) = self._treeview_tags.get_cursor()
-            if path is None:
-                return  # The widget is being destroyed.
             revision = self._model[path][1]
             self._revisionview.set_revision(self.branch.repository.get_revision(revision))
 

=== modified file 'tests/test_annotate_config.py'
--- tests/test_annotate_config.py	2012-02-09 03:01:20 +0000
+++ tests/test_annotate_config.py	2011-09-04 03:53:20 +0000
@@ -16,8 +16,6 @@
 
 """Test the annotate configuration functionality."""
 
-import os
-
 from bzrlib import (
     tests,
     )
@@ -26,7 +24,6 @@
     config,
     gannotate,
     )
-from bzrlib.plugins.gtk.annotate.config import gannotate_config_filename
 
 
 class TestConfig(tests.TestCaseInTempDir):
@@ -48,15 +45,3 @@
         width = conf['window']['width']
         # configobj presents attributes as strings only
         self.assertIsInstance(width, str)
-
-    def test_write(self):
-        """The window state and pane position is saved."""
-        conf = config.GAnnotateConfig(self.window)
-        self.window.pane.set_position(200)
-        self.assertIs(False, conf._write())
-        self.assertEqual(200, conf['window']['pane_position'])
-        config_path = gannotate_config_filename()
-        self.assertIs(True, os.path.isfile(config_path))
-        with open(config_path) as config_file:
-            config_data = config_file.read()
-        self.assertIn('pane_position = 200', config_data)

=== modified file 'tests/test_commit.py'
--- tests/test_commit.py	2012-02-03 22:59:09 +0000
+++ tests/test_commit.py	2012-01-23 16:52:40 +0000
@@ -17,8 +17,6 @@
 """Test the Commit functionality."""
 
 import os
-import subprocess
-from tempfile import NamedTemporaryFile
 
 from gi.repository import Gtk
 
@@ -1298,32 +1296,3 @@
         self.assertEquals(u'', self._get_commit_message())
         self.assertEquals(u'de',
                           self._get_file_commit_messages())
-
-
-class BzrHandlePatchTestCase(tests.TestCase):
-
-    def setUp(self):
-        top = os.path.abspath(os.path.join(
-            os.path.dirname(__file__), os.pardir))
-        self.script = os.path.join(top, 'bzr-handle-patch')
-        self.env = dict(os.environ)
-        self.env['BZR_PLUGINS_AT'] = 'gtk@%s' % top
-        self.patch = NamedTemporaryFile()
-        self.patch.write('\n'.join([
-            "=== added file '_test.txt'",
-            "--- _test.txt	1970-01-01 00:00:00 +0000",
-            "+++ _test.txt	2012-02-03 20:00:34 +0000",
-            "@@ -0,0 +1,1 @@",
-            "+hello",
-            ]))
-        self.patch.flush()
-        super(BzrHandlePatchTestCase, self).setUp()
-
-    def test_smoketest(self):
-        # This is a smoke test to verify the process starts.
-        bzr_notify = subprocess.Popen(
-            [self.script, self.patch.name, 'test'],
-            stdout=subprocess.PIPE, stderr=subprocess.PIPE, env=self.env)
-        stdout, stderr = bzr_notify.communicate()
-        self.assertEqual('', stdout)
-        self.assertEqual('', stderr)

=== modified file 'tests/test_diff.py'
--- tests/test_diff.py	2012-02-05 05:14:11 +0000
+++ tests/test_diff.py	2012-01-23 18:10:44 +0000
@@ -15,6 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+from cStringIO import StringIO
 import os
 
 from gi.repository import Gtk
@@ -32,11 +33,8 @@
 
 from bzrlib.plugins.gtk.diff import (
     DiffController,
-    DiffFileView,
     DiffView,
     DiffWidget,
-    DiffWindow,
-    have_gtksourceview,
     iter_changes_to_status,
     MergeDirectiveController,
     )
@@ -62,29 +60,24 @@
  class TestDiffViewSimple(tests.TestCase):
 """
 
-
-class FakeDiffFileView(DiffFileView):
-
-    SHOW_WIDGETS = False
-
-
-class DiffFileViewTestCase(tests.TestCase):
-
-    def test_init_construct(self):
-        view = FakeDiffFileView()
-        self.assertIsNot(None, view.buffer)
-        self.assertIsNot(None, view.sourceview)
-        self.assertIs(False, view.sourceview.props.editable)
-        font_desc = view.sourceview.get_style_context().get_font(
-            Gtk.StateFlags.NORMAL)
-        self.assertIn('Monospace', font_desc.get_family())
-
-    def test_init_construct_have_gtksourceview(self):
-        if not have_gtksourceview:
-            return
-        view = FakeDiffFileView()
-        self.assertEqual('Diff', view.buffer.get_language().get_name())
-        self.assertIs(True, view.buffer.get_highlight_syntax())
+class TestDiffViewSimple(tests.TestCase):
+
+    def test_parse_colordiffrc(self):
+        colordiffrc = '''\
+newtext=blue
+oldtext = Red
+# now a comment and a blank line
+
+diffstuff = #ffff00  
+  # another comment preceded by whitespace
+'''
+        colors = {
+                'newtext': 'blue',
+                'oldtext': 'Red',
+                'diffstuff': '#ffff00',
+        }
+        parsed_colors = DiffView.parse_colordiffrc(StringIO(colordiffrc))
+        self.assertEqual(colors, parsed_colors)
 
 
 class TestDiffView(tests.TestCaseWithTransport):
@@ -138,65 +131,6 @@
         self.assertFalse(widget.diff_view.show_diff.called)
 
 
-class FakeDiffWindow(DiffWindow):
-
-    SHOW_WIDGETS = False
-
-
-class DiffWindowTestCase(tests.TestCaseWithTransport):
-
-    def test_init(self):
-        window = DiffWindow()
-        self.assertEqual('bzr diff', window.props.title)
-        self.assertEqual(0, window.props.border_width)
-
-    def test_init_construct_without_operations(self):
-        window = DiffWindow()
-        widgets = window.vbox.get_children()
-        self.assertEqual(2, len(widgets))
-        self.assertIsInstance(widgets[0], Gtk.MenuBar)
-        self.assertIsInstance(widgets[1], DiffWidget)
-
-    def test_init_construct_with_operations(self):
-        method = MockMethod()
-        window = DiffWindow(operations=[('title', method)])
-        widgets = window.vbox.get_children()
-        self.assertEqual(3, len(widgets))
-        self.assertIsInstance(widgets[0], Gtk.MenuBar)
-        self.assertIsInstance(widgets[1], Gtk.HButtonBox)
-        self.assertIsInstance(widgets[2], DiffWidget)
-
-    def test_get_menu_bar(self):
-        window = DiffWindow()
-        menu_bar = window._get_menu_bar()
-        self.assertIsNot(None, menu_bar)
-        menus = menu_bar.get_children()
-        self.assertEqual(1, len(menus))
-        self.assertEqual('_View', menus[0].props.label)
-        sub_menu = menus[0].get_submenu()
-        self.assertIsNot(None, sub_menu)
-        items = sub_menu.get_children()
-        self.assertEqual(1, len(items))
-        menus[0].get_submenu().get_children()[0].props.label
-        self.assertEqual('Wrap _Long Lines', items[0].props.label)
-
-    def test_get_button_bar_with_none(self):
-        window = DiffWindow()
-        self.assertIs(None, window._get_button_bar(None))
-
-    def test_get_button_bar_with_operations(self):
-        window = DiffWindow()
-        method = MockMethod()
-        button_bar = window._get_button_bar([('title', method)])
-        self.assertIsNot(None, button_bar)
-        buttons = button_bar.get_children()
-        self.assertEqual(1, len(buttons))
-        self.assertEqual('title', buttons[0].props.label)
-        buttons[0].emit('clicked')
-        self.assertIs(True, method.called)
-
-
-
 class MockDiffWidget(object):
 
     def set_diff_text_sections(self, sections):

=== modified file 'tests/test_notify.py'
--- tests/test_notify.py	2012-02-03 23:03:02 +0000
+++ tests/test_notify.py	2012-02-03 19:49:55 +0000
@@ -42,21 +42,14 @@
 
 class BzrNotifyTestCase(tests.TestCase):
 
-    def setUp(self):
-        top = os.path.abspath(os.path.join(
-            os.path.dirname(__file__), os.pardir))
-        self.script = os.path.join(top, 'bzr-notify')
-        self.env = dict(os.environ)
-        self.env['BZR_PLUGINS_AT'] = 'gtk@%s' % top
-        super(BzrNotifyTestCase, self).setUp()
-
     def test_smoketest(self):
         # This is a smoke test to verify the process starts.
         # The logic of the module must be moved into notify.py
         # where it can be properly tested.
+        script = os.path.join(
+            os.path.dirname(__file__), os.pardir, 'bzr-notify')
         bzr_notify = subprocess.Popen(
-            [self.script, 'test'],
-            stdout=subprocess.PIPE, stderr=subprocess.PIPE, env=self.env)
+            [script, 'test'], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
         stdout, stderr = bzr_notify.communicate()
         self.assertEqual('', stdout)
         self.assertEqual('', stderr)

=== modified file 'viz/branchwin.py'
--- viz/branchwin.py	2012-02-09 03:43:01 +0000
+++ viz/branchwin.py	2011-11-29 10:09:23 +0000
@@ -136,7 +136,7 @@
         if self.config.get_user_option('viz-vertical') == 'True':
             self.paned = Gtk.HPaned()
         else:
-            self.paned = Gtk.Paned.new(Gtk.Orientation.VERTICAL)
+            self.paned = Gtk.VPaned()
 
         self.paned.pack1(self.construct_top(), resize=False, shrink=True)
         self.paned.pack2(self.construct_bottom(), resize=True, shrink=False)
@@ -371,7 +371,7 @@
     def construct_bottom(self):
         """Construct the bottom half of the window."""
         if self.config.get_user_option('viz-wide-diffs') == 'True':
-            self.diff_paned = Gtk.Paned.new(Gtk.Orientation.VERTICAL)
+            self.diff_paned = Gtk.VPaned()
         else:
             self.diff_paned = Gtk.HPaned()
         (width, height) = self.get_size()

